@@ -298,7 +298,7 @@ impl Visit for SpanVisualizer<'_> {
     mtd!(TypeSelector, visit_type_selector);
     mtd!(Number, visit_number);
     mtd!(Ratio, visit_ratio);
-    mtd!(PercentValue, visit_percent_value);
+    mtd!(Percent, visit_percent);
     mtd!(Declaration, visit_declaration);
     mtd!(Nth, visit_nth);
     mtd!(AnPlusB, visit_an_plus_b);
